@@ -1,4 +1,4 @@
-import requests, time
+import requests, time,os
 from sreup.Client import Client
 import multiprocessing
 from sreup.common import config
@@ -11,7 +11,8 @@ class ThreadMain:
                     break
                 obj = requests.get(config.ServerAdress.REUP_SERVER + "job/get", headers={"Bas-Name": "AutoWin"}).json()
                 if 'id' in obj:
-                    client = Client(obj['id'], obj['gmail'], obj['task_list'], config.Timeout.CLIENT)
+                    timeout = os.getenv('FF_CLIENT_TIMEOUT', config.Timeout.CLIENT)
+                    client = Client(obj['id'], obj['gmail'], obj['task_list'], int(timeout))
                     client.start()
                     client.wait()
                     print('done')
